"""
VSA Memory & File functions
 _____  _____   ____ _______ ____ _________     _______  ______
|  __ ||  __ | / __ |__   __/ __ |__   __| |   / /  __ ||  ____|
| |__) | |__) | |  | | | | | |  | | | |   | |_/ /| |__) | |__
|  ___/|  _  /| |  | | | | | |  | | | |    |   / |  ___/|  __|
| |    | | | || |__| | | | | |__| | | |     | |  | |    | |____
|_|    |_|  |_||____/  |_|  |____/  |_|     |_|  |_|    |______|
                        _            _           _
                       | |          | |         | |
            _   _ _ __ | |_ ___  ___| |_ ___  __| |
           | | | | '_ || __/ _ |/ __| __/ _ |/ _` |
           | |_| | | | | ||  __/|__ | ||  __/ (_| |
            |__,_|_| |_||__|___||___/|__|___||__,_|
"""
##########################################################
### User Entry
##########################################################
VSA_IP  = '192.168.1.108'
##########################################################
### Code Overhead
##########################################################
from rssd.VSA.Common        import VSA              #pylint: disable=E0611,E0401
# from rssd.yaVISA_socket     import jaVisa           #pylint: disable=E0611,E0401
VSA = VSA().jav_Open(VSA_IP)                        #Create VSA Object

##########################################################
### Code Start
##########################################################
print(VSA.query(':MMEM:CAT? '))
print(VSA.query(':MMEM:CAT? "autologin.reg"'))

##########################################################
### Cleanup Automation
##########################################################
VSA.jav_Close()
